<!DOCTYPE TS><TS>
<context encoding="UTF-8">
    <name>AboutDialog</name>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>Navegador lixeiro baseado en WebKit</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autores</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Pechar</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message encoding="UTF-8">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;(new line)
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;(new line)
p, li { white-space: pre-wrap; }(new line)
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;(new line)
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation>WebKit versión: %1</translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Idiomas</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Idiomas: en orde de preferencia:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover cara &amp;arriba</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover cara a&amp;baixo</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Engadir...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation>Bloqueado pola regra AdBlock: %1</translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation>Engadir regra personalizada</translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation>Aprender máis de como escribir regras...</translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation>Actualizar a subscripción</translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation>Examinar as subscripcións...</translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation>Eliminar a subscripción</translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation>Configuración de AdBlock</translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation>Activar AdBlock</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation>Regras personalizadas</translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation>Regra</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation>Subscribir?</translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation>Aceptar esta subscripción AdBlock?
%1</translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Engadir marcador</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Introduza un nome para o marcador e elixa onde gardalo.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Engadir cartafol</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation>Formulario de contrasinais</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation>Eliminar todo</translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation>&lt;b&gt;Desexa gardar este contrasinal?&lt;/b&gt;&lt;br&gt;         Para revisar e eliminar os contrasinais gardados, abra o panel Autocompletar de Preferencias.</translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation>Nunca para este sitio</translation>
    </message>
    <message>
        <source>Not now</source>
        <translation>Agora non</translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation>Páxina web</translation>
    </message>
    <message>
        <source>User Name</source>
        <translation>Nome de usuario</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Engadir cartafol</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Abrir nunha lingüeta nova</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Novo cartafol</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Editar nome</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Editar enderezo</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Atopouse un erro cargando os marcadores na liña %1, columna %2:
%3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Barra de marcadores</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menú</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir ficheiro</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Importado %1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Gardar ficheiro</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Bookmarks.xbel</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Atopouse un erro durante a exportación</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>atopouse un erro gardando os marcadores</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Eliminar marcador</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Inserir marcador</translation>
    </message>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Barra de marcadores</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Menú de marcadores</translation>
    </message>
    <message>
        <source>Error when loading html bookmarks: %1
</source>
        <translation type="obsolete">Atopouse un erro mentras se cargaban os marcadores html: %1
</translation>
    </message>
    <message>
        <source>XBEL</source>
        <translation type="obsolete">XBEL</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation>Cambiar o nome</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation>Cambiar o enderezo</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation>Marcadores XBEL</translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation>Marcadores HTML de Netscape</translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation>Precisase a ferramenta htmlToXBel </translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation>A ferramenta htmlToXBel , que se inclue con Arora e é precisa para importar os marcadores HTML, non está instalada ou non está dispoñible no camiño de buscas.</translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation>Cargando marcador</translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation>Atopouse un erro mentras se cargaban os marcadores HTML: %1
</translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>Abrir en lingüetas</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Enderezo</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Marcador</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Abrir nunha lingüe&amp;ta nova</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Engadir marcador...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Engadir cartafol...</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Marcadores</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete"> (Cambio: %1 %2)</translation>
    </message>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Hai %1 ventá e %2 lingüetas abertas
Desexa saír de todos os xeitos?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Fallou a recuperación</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">Non se puido recuperar a sesión gardada xaque  Arora fallou a última vez que se recuperou .</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation>Arora pechouse inesperadamente mentres tentaba recuperar esta sesión.  Tentalo de novo?</translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Nova ventá</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>&amp;Abrir ficheiro...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>Abrir &amp;ubicación...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Gardar como...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Importar marcadores...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Exportar marcadores...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>Vista p&amp;revia de impresión...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>I&amp;mprimir...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>&amp;Navegación privada...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Saír</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Desfacer</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Refacer</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;pegar</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Buscar</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>Buscar &amp;seguinte</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>Buscar &amp;anterior</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">&amp;Preferencias...</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Amosar barra de menús</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="obsolete">Maiús+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Deter</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>&amp;Recargar páxina</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>Código f&amp;onte</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Pantalla &amp;completa</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>&amp;Historial</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Atras</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Adiante</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Recuperar última sesión</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Marcadores</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Engadir marcador...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ventá</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Ferramentas</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>&amp;Busca na web</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>&amp;Limpar datos privados</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Maiús+Supr</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Activar o &amp;inspector da web</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;xuda</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navegación</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Amosar a barra de estado</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Agochar a barra de estado</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Amosar a barra de ferramentas</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Agochar a barra de ferramentas</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Amosar a barra de marcadores</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Agochar a barra de marcadores</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Abrir os recursos da web</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Recursos da web (*.html *.htm *.svg *.png *.gif *.svgz);;Todos os ficheiros (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Imprimir documentación</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Está seguro de querer activar a navegación privada?</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Está seguro de que quere pechar a ventá?  Hai %1 lingüetas abertas</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Inspector da web</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>O inspectorda  web só funcionará correctamente coas páxinas que se carguen despois de activalo.
Desexa recargar tódalas páxinas?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Deter a carga da páxina actual</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Recargar a páxina actual</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <source>Show &amp;Network Monitor</source>
        <translation type="obsolete">Amosar mo&amp;nitor de rede</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Cambiar o idioma da aplicación </translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Pechar ventá</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;aumentar</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>Zoom &amp;normal</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;reducir</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Zoom &amp;só texto</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation>Acerca de &amp;%1</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Amosar tódolos marcadores...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Engadir cartafol...</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Cando se activa a navegación privada, algunhas accións relativas a súa intimidade han de ser desactivadas:&lt;ul&gt;&lt;li&gt; As páxinas web non serán engadidas ao historial.&lt;/li&gt;&lt;li&gt; Hanse eliminar automaticamente os elementos no xestor de descargas.&lt;/li&gt;&lt;li&gt; Non se almacenarán as novas cookies e as actuais non estarán accesibles.&lt;/li&gt;&lt;li&gt; As iconas dos sitios non han ser gardadas e tampouco as sesións.&lt;/li&gt;&lt;li&gt; As buscas non serán engadidas no menú emerxente da caixa de buscas.&lt;/li&gt;&lt;/ul&gt;Poderá facer clic nos botóns Adiante e Atrás para volver as páxinas visitadas, pero só mentres non peche a ventá.</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Codificación do texto</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; Network cache is disabled.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Cando se activa a navegación privada, algunhas accións relativas a súa intimidade han de ser desactivadas:&lt;ul&gt;&lt;li&gt; As páxinas web non serán engadidas ao historial.&lt;/li&gt;&lt;li&gt; Hanse eliminar automaticamente os elementos no xestor de descargas.&lt;/li&gt;&lt;li&gt; Non se almacenarán as novas cookies e as actuais non estarán accesibles.&lt;/li&gt;&lt;li&gt; As iconas dos sitios non han ser gardadas e tampouco as sesións.&lt;/li&gt;&lt;li&gt;Desactivase a caché de rede.&lt;/li&gt;&lt;/ul&gt;Poderá facer clic nos botóns Adiante e Atrás para volver as páxinas visitadas, pero só mentres non peche a ventá.</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Seleccionar &amp;todo</translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation>Alt+Ctrl+B</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; No new network cache is written to disk.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Cando se activa a navegación privada, algunhas accións relativas a súa intimidade han de ser desactivadas:&lt;ul&gt;&lt;li&gt; As páxinas web non serán engadidas ao historial.&lt;/li&gt;&lt;li&gt; Hanse eliminar automaticamente os elementos no xestor de descargas.&lt;/li&gt;&lt;li&gt; Non se almacenarán as novas cookies e as actuais non estarán accesibles.&lt;/li&gt;&lt;li&gt; As iconas dos sitios non han ser gardadas e tampouco as sesións.&lt;/li&gt;&lt;li&gt; A nova caché de rede non se vai grabar no disco.&lt;/li&gt;&lt;/ul&gt;Poderá facer clic nos botóns Adiante e Atrás para volver as páxinas visitadas, pero só mentres non peche a ventá.</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opcións...</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation>Configurar os motores de busca...</translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation>&amp;Bloquear publicidade...</translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation>Cuando se activa a navegación privada, desactivaránse algunhas accións relacionadas coa súa intimidade:</translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation>As páxinas web no serán engadidas ao historial.</translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation>Eliminaránse automaticamente os elementos da ventá de descargas.</translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation>Non se gardarán as novas cookies, no se poderá acceder as cookies actuais.</translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation>Non se gardarán as iconas da páxina.</translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation>Non se gardará a sesión.</translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation>As buscas non serán engadidas ao menú emerxente no cadro de buscas.</translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation>No se escribirá no disco a nova caché da rede.</translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation>Até que se peche a ventá, vostede poderá facer clic nos botóns Atrás e Adiante para volver ás páxinas web que teña aberto.</translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation>Navegación privada</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Limpar datos privados</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Limpar os seguintes elementos:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>Historial de &amp;navegación</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>Historial de &amp;descargas</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>Historial de &amp;buscas</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Cookies</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>C&amp;Aché de páxinas visitadas</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>&amp;Iconas das páxinas web</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>&amp;Limpar datos privados</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation>Cargar<byte value="x9"/></translation>
    </message>
    <message>
        <source>Load All</source>
        <translation>Cargar todo</translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation>Engadir %1 á lista branca</translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation>Quitar da lista branca</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation>Cargar «Flash»</translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation>Lista branca de sitios</translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Regra</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Permitir</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Permitir só para esta sesión</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Ruta</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Seguro</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Caduca</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Contido</translation>
    </message>
    <message>
        <source>true</source>
        <translation>verdadeiro</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falso</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation>Cookie da sesión</translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Eliminar &amp;tódalas cookies</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation>Engadir &amp;regra</translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Cookies exentas</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Nova excepción</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Dominio:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Permitir só para esta sesión</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Permitir</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Excepcións</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Eliminar &amp;todas</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Baleirar</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 Elementos</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formulario</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Icona</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nome de ficheiro</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Rentar de novo</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Deter</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Gardar ficheiro</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Descarga cancelada: %1</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Atopouse un erro ao abrir o ficheiro de sída: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Atopouse un erro gardando: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Atopouse un erro na rede: %1</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 de %2 - Detida</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1 de %2 (%3/segs.) - %4</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation>O directorio de descarga (%1)non se pode crear.</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%n Download(s)</source>
        <translation>%n Descarga(s)
        
        
        
        
        
        </translation>
    </message>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>Hai %1 descargas en proceso
Saír de tódolos xeitos?</translation>
    </message>
    <message>
        <source>%n minutes remaining</source>
        <translation>Faltan %n minutos
        
        
        
        </translation>
    </message>
    <message>
        <source>%n seconds remaining</source>
        <translation>Faltan %n segundos
        
        
        
        
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <translation>GB</translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation>Sen erro</translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation>Atopouse un erro ao abrir: %1: Non existe o ficheiro ou directorio</translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation>Non se pode ler %1</translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation>Contido de %1</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Eliminar &amp;todo</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borar</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Amosar todo o historial</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Limpar historial...</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Limpar historial</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Desexa limpar todo o historial?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Enderezo</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Antes de hoxe</translation>
    </message>
    <message>
        <source>%n item(s)</source>
        <translation>%n elemento(s)
        
        
        
        
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation>Benvido a Arora!</translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation>Iniciar Arora</translation>
    </message>
    <message>
        <source>Search!</source>
        <translation>Busca!</translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation>Resultados da busca fornecidos por</translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation>Acerca de Arora</translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>Choose language</source>
        <translation>Elixir idioma</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Pode executarse cun idioma distinto&lt;br&gt;ao predeterminado do sistema operativo.&lt;/p&gt;&lt;p&gt;Por favor, elixa o idioma que desexe empregar&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed.</source>
        <translation type="obsolete">Os ficheiros de tradución non están instalados.</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation>Non hai ficheiros de tradución instalados en %1.</translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Introduza un nome de usuario e un contrasinal para &quot;%1&quot; at %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Conectar ao proxy &quot;%1&quot; usando:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Erros SSL:&lt;br/&gt;&lt;br/&gt;para: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Ignorar estes erros?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Certificados:&lt;br/&gt;%1&lt;br/&gt;Aceptar todos estes certificados?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation> - Erros SSL</translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation>Emisor: %1</translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation>Non é válido antes de: %1</translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation>Válido até o: %1</translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation>Nomes alternativos:</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Nome</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="obsolete">Valor</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>Network Monitor</source>
        <translation type="obsolete">Monitor de rede</translation>
    </message>
    <message>
        <source>Network Requests</source>
        <translation type="obsolete">Solicitudes de rede</translation>
    </message>
    <message>
        <source>Request Headers</source>
        <translation type="obsolete">Cabeceiras das solicitudes</translation>
    </message>
    <message>
        <source>Response Headers</source>
        <translation type="obsolete">Cabeceiras de resposta</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Eliminar</translation>
    </message>
    <message>
        <source>Remove &amp;All Requests</source>
        <translation type="obsolete">Eliminar &amp;tódalas solicitudes</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation>Abrir ficheiro</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation>OpenSearch</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation>%1 non é unha descrición correcta para OpenSearch 1.1 ou xa está na súa lista.</translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation>Debe ter aquí polo menos un motor de busca.</translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation>Xestor OpenSearch</translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation>&amp;Restaurar predeterminados</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Engadir</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Pechar</translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation>&lt;strong&gt;Descrición:&lt;/strong&gt; %1</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation>Fornece suxestións contextuais</translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation>Lista separada por comas das palabras clave que se poden introducir na barra seguidas dos termos de busca para buscar con este motor</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Palabras clave</translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation>Quere engadir o seguinte motor á súa lista de motores de busca?&lt;br /&gt;&lt;br /&gt;Nome: %1&lt;br /&gt;Buscas en: %2</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Precisa autenticarse</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>ICONA SIMULADA</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>INTRODUZA TEXTO SIMULADO</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasinal:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Non atopado</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Autenticación no proxi</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Conectar ao proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasinal:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>OP ficheiro non é un ficheiro XBEL versión 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Título descoñecido</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation>Este ficheiro non é un ficheiro OpenSearch 1.1.</translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Redirect: %1</source>
        <translation type="obsolete">Redirixe a: %1</translation>
    </message>
    <message>
        <source>Method</source>
        <translation type="obsolete">Método</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">Enderezo</translation>
    </message>
    <message>
        <source>Response</source>
        <translation type="obsolete">Resposta</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Lonxitude</translation>
    </message>
    <message>
        <source>Content Type</source>
        <translation type="obsolete">Tipo de contido</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Información</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formulario</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation>Destacar todo</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Xeral</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>No inicio:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Amosar a miña páxina de inicio</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Amosar a páxina en branco</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Recuperar ventás e lingüetas da última sexión</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Páxina de inicio:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Páxina actual como predeterminada</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Eliminar os elementos do historial:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Despois de un día</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Despois de unha semana</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Despois de dúas semanas</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Despois de un mes</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Despois de un ano</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Manualmente</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>Ao sair da aplicación</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Abrir ligazóns de aplicacións:</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>Nunha nova ventá</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Preguntar en cada caso</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Usar este destino:</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Aparencia</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Fonte estándar:</translation>
    </message>
    <message>
        <source>Times 16</source>
        <translation type="obsolete">Times 16</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Seleccionar...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Fonte de anchura fixa:</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privacidade</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Contido da web</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Activar extensión</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Activar Javascript</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Ver imaxes</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Aceitar cookies:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Só dende os sitios que se visiten</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Excepcións...</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Manter até que:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>Caduquen</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>Se saia da aplicación</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>Un máximo de 90 días</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Cookies...</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Lingüetas</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Seleccionar lingüetas e ventás ao ser creadas</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Usar servidor proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Nome da máquina:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Porto:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Nome de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasinal:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Estilo de folla:</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Amosar só un botón de peche no canto de un para cada lingüeta</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Bloquear ventás emerxentes</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Abrindo ligazóns</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Ligazóns que desexa abrir nunha nova ventá:</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>Na lingüeta seleccionada na ventá actual</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>Nunha nova lingüeta na ventá ctual</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>Na lingüeta actual</translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>Http (Seguro)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation>Http (Transparente)</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Idiomas preferidos para ver páxinas web en:</translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation>Use ClickToFlash nas estensións flash</translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation>Filtrar as cookies de seguimento</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation>Pedir confirmación cando se pechen multiples lingüetas ou ventás</translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation>Sair da aplicación cando se peche a última lingüeta</translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation>Activar a caché de rede</translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation>Tamaño máximo:</translation>
    </message>
    <message>
        <source> MB</source>
        <translation> MB</translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation>Use o motor de buscas predeterminado como último recurso cando a URL dada polo usuario non é correcta</translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation>Escoller directorio...</translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation>Unha cookie de sesión caduca:</translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation>Cando saia do aplicativo</translation>
    </message>
    <message>
        <source>1 day</source>
        <translation>1 día</translation>
    </message>
    <message>
        <source>2 days</source>
        <translation>2 días</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 días</translation>
    </message>
    <message>
        <source>7 days</source>
        <translation>7 días</translation>
    </message>
    <message>
        <source>30 days</source>
        <translation>30 días</translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation>Autocompletado</translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation>Autocompletado de formularios web:</translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation>Nomes de usuario e contrasinais</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Editar...</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Examinar...</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation>É preciso reiniciar</translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation>A configuración da caché de rede cambiou. A fin de que poida ser tida en conta, o navegador ten de ser reiniciado.</translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation>Escoller directorio</translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation>Escoller ficheiro CSS</translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Buscar</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">A&amp;xustar as liñas</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">Código fonte da páxina </translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation>Código fonte da páxina %1</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>Show Tab Bar</source>
        <translation>Amosar barra de lingüetas</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Agochar barra de lingüetas</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Duplicar a lingüeta</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Pechar a lingüeta</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Pechar as &amp;outras lingüetas</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Recargar lingüeta</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Recargar tódalas lingüetas</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nova lingüe&amp;ta</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Pechar a lingüeta</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Amosar a seguinte lingüeta</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Amosar a lingüeta anterior</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Lingüetas abertas recentemente</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Desexa realmente pechar esta páxina?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Esta páxina foi modificada e si a pecha perderá os cambios.
Está seguro de que quere pechar esta páxina?
</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation>Ctrl-]</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation>Ctrl-[</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>Lingüetas gardadas</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>Cargando %1% (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>rematou a descarga</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>Atopouse un fallo duranre a descarga</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Tódalas lingüetas a marcadores</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>No Recent Searches</source>
        <translation>Non hai buscas recentes</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Buscas recentes</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Limpar buscas recentes</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suxestions</translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation>Engadir «%1»</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="obsolete">Configurar motores de busca...</translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Atopouse un erro ao cargar a páxina: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>Cando se conecta a: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Comprobe que non hai erros no enderezo como&lt;b&gt;ww&lt;/b&gt;.arora-browser.org no canto de &lt;b&gt;www&lt;/b&gt;.arora-browser.org</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Se a súa computadora ou rede están protexidas por unha devasa ou un proxy, asegúrese de que ao navegador se lle permite o acceso á rede.</translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Se o enderezo é correcto, comprobe a conexión de rede.</translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation>Reenviar unha solicitude POST</translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation>Para amosar o sitio web, a solicitude, xunto con todos os datos deben ser enviados, unha vez máis, o que pode levar a algun comportamento inesperado do sitio por exemplo, a mesma acción pode ser realizada unha vez máis. Quere continuar igualmente?</translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Abrir nunha &amp;ventá nova</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Abrir nunha lingüe&amp;ta nova</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Gardar &amp;ligazón</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>Engadir esta páxina a &amp;marcadores</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Copiar o enderezo da ligazón</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Abrir a imaxe nunha &amp;ventá nova</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Abrir a imaxe nunha lingüe&amp;ta nova</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>&amp;Gardar a imaxe</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>&amp;Copiar a imaxe</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>C&amp;opiar a ubicación da imaxe</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation>Buscar con...</translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation>Engadir á barra de ferramentas de busca</translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation>Método non compatible</translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation>O método %1 non é compatible.</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Motor de buscas</translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation>Elixir o motor de busca desexado</translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation>Nome do motor</translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation>Escriba un nome para o motor</translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation>Bloquear imaxe</translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Non atopado</translation>
    </message>
</context>
</TS>
